@@ -16,13 +16,12 @@
  * along with this program; if not, write to the Free Software            *
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA          *
  * 02110-1301, USA.                                                       *
-***************************************************************************/
+ ***************************************************************************/
 
 #ifndef MENUPROXYMODEL_H
 #define MENUPROXYMODEL_H
 
 #include <KCategorizedSortFilterProxyModel>
-#include "systemsettingsview_export.h"
 
 /**
  * @brief Provides a filter model for MenuModel
@@ -33,10 +32,10 @@
  * Call setFilterRegExp(QString) with the desired text to filter to perform searching.
  * Items that do not match the search parameters will be disabled, not hidden.
  *
- * @author Will Stephenson <wstephenson@kde.org> 
+ * @author Will Stephenson <wstephenson@kde.org>
  * @author Ben Cooksley <bcooksley@kde.org>
  */
-class SYSTEMSETTINGSVIEW_EXPORT MenuProxyModel : public KCategorizedSortFilterProxyModel
+class MenuProxyModel : public KCategorizedSortFilterProxyModel
 {
     Q_OBJECT
 
@@ -48,29 +47,29 @@ public:
      *
      * @param parent The QObject to use as a parent.
      */
-    MenuProxyModel( QObject *parent = 0 );
+    MenuProxyModel(QObject *parent = nullptr);
 
-    QHash<int, QByteArray> roleNames() const Q_DECL_OVERRIDE;
+    QHash<int, QByteArray> roleNames() const override;
 
     /**
      * Please see the Qt QSortFilterProxyModel documentation for further information.\n
      * Provides information on whether or not the QModelIndex specified by left is below right.
      *
      * @param left the QModelIndex that is being used for comparing.
-     * @param right the QModelIndex to compare aganist.
+     * @param right the QModelIndex to compare against.
      * @returns true if the left is below the right.
      */
-    bool lessThan( const QModelIndex &left, const QModelIndex &right ) const Q_DECL_OVERRIDE;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     /**
-     * Please see the KDE KCategorizedSortFilterProxyModel documentation for futher information.\n
+     * Please see the KDE KCategorizedSortFilterProxyModel documentation for further information.\n
      * Provides information on whether or not the QModelIndex specified by left is below right.
      *
      * @param left the QModelIndex that is being used for comparing.
-     * @param right the QModelIndex to compare aganist.
+     * @param right the QModelIndex to compare against.
      * @returns true if the left is below the right.
      */
-    bool subSortLessThan( const QModelIndex &left, const QModelIndex &right ) const Q_DECL_OVERRIDE;
+    bool subSortLessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     /**
      * Please see the Qt QSortFilterProxyModel documentation for futher information.\n
@@ -80,7 +79,7 @@ public:
      * @param source_parent Please see QSortFilterProxyModel documentation.
      * @returns true if the row should be displayed, false if it should not.
      */
-    bool filterAcceptsRow( int source_column, const QModelIndex &source_parent ) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int source_column, const QModelIndex &source_parent) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -89,26 +88,26 @@ public:
      *
      * @returns The flags for the QModelIndex provided.
      */
-    Qt::ItemFlags flags( const QModelIndex &index ) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
      * Reimplemented for internal reasons.
      */
-    void setFilterRegExp ( const QRegExp & regExp );
-    
+    void setFilterRegExp(const QRegExp &regExp);
+
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
      * Reimplemented for internal reasons.
      */
-    void setFilterRegExp ( const QString & pattern );
+    void setFilterRegExp(const QString &pattern);
 
     QString filterRegExp() const;
 
     /**
      * makes the filter highlight matching entries instead of hiding them
      */
-    void setFilterHighlightsEntries (bool highlight );
+    void setFilterHighlightsEntries(bool highlight);
 
     /**
      * @returns the filter highlight matching entries instead of hiding them, default true
